@@ -205,7 +205,7 @@ On-memory Hash Database.\n\
 \n\
 See also:\n\
 Tokyo Cabinet On-memory Hash Database API at:\n\
-http://1978th.net/tokyocabinet/spex-en.html#tcutilapi_mdbapi");
+http://fallabs.com/tokyocabinet/spex-en.html#tcutilapi_mdbapi");
 
 
 /* MDBType.tp_dealloc */
@@ -250,8 +250,8 @@ MDB_tp_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
 
 
 /* MDB_tp_as_sequence.sq_contains */
-static
-int MDB_Contains(MDB *self, PyObject *pykey)
+static int
+MDB_Contains(MDB *self, PyObject *pykey)
 {
     void *key, *value;
     int key_size, value_size;
