@@ -203,7 +203,7 @@ On-memory Tree Database.\n\
 \n\
 See also:\n\
 Tokyo Cabinet On-memory Tree Database API at:\n\
-http://1978th.net/tokyocabinet/spex-en.html#tcutilapi_ndbapi");
+http://fallabs.com/tokyocabinet/spex-en.html#tcutilapi_ndbapi");
 
 
 /* NDBType.tp_dealloc */
@@ -237,8 +237,8 @@ NDB_tp_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
 
 
 /* NDB_tp_as_sequence.sq_contains */
-static
-int NDB_Contains(NDB *self, PyObject *pykey)
+static int
+NDB_Contains(NDB *self, PyObject *pykey)
 {
     void *key, *value;
     int key_size, value_size;
