@@ -713,7 +713,7 @@ Table Database.\n\
 \n\
 See also:\n\
 Tokyo Cabinet Table Database API at:\n\
-http://1978th.net/tokyocabinet/spex-en.html#tctdbapi");
+http://fallabs.com/tokyocabinet/spex-en.html#tctdbapi");
 
 
 /* TDBType.tp_dealloc */
@@ -752,8 +752,8 @@ TDB_tp_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
 
 
 /* TDB_tp_as_sequence.sq_contains */
-static
-int TDB_Contains(TDB *self, PyObject *pykey)
+static int
+TDB_Contains(TDB *self, PyObject *pykey)
 {
     void *key;
     int key_size;
