@@ -30,6 +30,7 @@
 
 
 #define TK_PY_MAX_DB_LEN ((unsigned long long)PY_SSIZE_T_MAX)
+#define TK_PY_MAX_ID ((unsigned long long)INT64_MAX)
 
 #if SIZEOF_SIZE_T > SIZEOF_INT
 #define TK_PY_SIZE_T_BIGGER_THAN_INT
@@ -67,7 +68,6 @@ set_stopiteration_error(void)
 }
 
 
-#if PY_MAJOR_VERSION >= 3
 /* PyUnicode to char * */
 char *
 PyUnicode_AS_STRING(PyObject *unicode)
@@ -86,15 +86,19 @@ PyUnicode_AS_STRING(PyObject *unicode)
 }
 
 char *
-PyUnicode_AsString(PyObject *unicode)
+PyUnicode_AsString(PyObject *obj)
 {
-    if (!PyUnicode_Check(unicode)) {
-        PyErr_SetString(PyExc_TypeError, "a string is required");
-        return NULL;
+    if (PyUnicode_Check(obj)) {
+        return PyUnicode_AS_STRING(obj);
     }
-    return PyUnicode_AS_STRING(unicode);
+    if (PyBytes_Check(obj)) {
+        return PyBytes_AS_STRING(obj);
+    }
+    PyErr_SetString(PyExc_TypeError, "a bytes or unicode object is required");
+    return NULL;
 }
 
+#if PY_MAJOR_VERSION >= 3
 #define PyString_AsString PyUnicode_AsString
 #define PyString_FromString PyUnicode_FromString
 #define PyInt_FromLong PyLong_FromLong
@@ -311,6 +315,50 @@ DB_Length(unsigned long long len)
 }
 
 
+long long
+uint64_to_int64(unsigned long long id)
+{
+    if (id > TK_PY_MAX_ID) {
+        set_error(PyExc_OverflowError, "key is greater than maximum");
+        return -1;
+    }
+    return (long long)id;
+}
+
+/* convert an array of ids to a fozenset */
+PyObject *
+ids_to_frozenset(uint64_t *result, int result_size)
+{
+    int i;
+    long long id;
+    PyObject *pyresult, *pyid;
+
+    pyresult = PyFrozenSet_New(NULL);
+    if (!pyresult) {
+        return NULL;
+    }
+    for(i = 0; i < result_size; i++){
+        id = uint64_to_int64(result[i]);
+        if (id == -1) {
+            Py_DECREF(pyresult);
+            return NULL;
+        }
+        pyid = PyLong_FromLongLong(id);
+        if (!pyid) {
+            Py_DECREF(pyresult);
+            return NULL;
+        }
+        if (PySet_Add(pyresult, pyid)) {
+            Py_DECREF(pyid);
+            Py_DECREF(pyresult);
+            return NULL;
+        }
+        Py_DECREF(pyid);
+    }
+    return pyresult;
+}
+
+
 /*******************************************************************************
 * DBIter
 *******************************************************************************/
